summaryrefslogtreecommitdiffstats
path: root/krdc
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:33:51 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:33:51 -0600
commit089118c18533dfa3e6ce5065dbebdd4db94051f1 (patch)
treece014fb2326a80fcfafa2362b7ff88486aa17c96 /krdc
parent83677e35509b4dafac63b76995652bdf3b49f209 (diff)
downloadtdenetwork-089118c18533dfa3e6ce5065dbebdd4db94051f1.tar.gz
tdenetwork-089118c18533dfa3e6ce5065dbebdd4db94051f1.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'krdc')
-rw-r--r--krdc/events.h10
-rw-r--r--krdc/hostprofiles.ui2
-rw-r--r--krdc/keycapturewidget.ui6
-rw-r--r--krdc/kfullscreenpanel.cpp2
-rw-r--r--krdc/krdc.cpp24
-rw-r--r--krdc/krdc.h4
-rw-r--r--krdc/kremoteview.cpp8
-rw-r--r--krdc/kremoteview.h18
-rw-r--r--krdc/maindialogbase.ui8
-rw-r--r--krdc/maindialogwidget.cpp4
-rw-r--r--krdc/rdp/krdpview.cpp16
-rw-r--r--krdc/rdp/krdpview.h2
-rw-r--r--krdc/rdp/rdpprefs.ui6
-rw-r--r--krdc/vnc/kvncview.cpp12
-rw-r--r--krdc/vnc/kvncview.h2
-rw-r--r--krdc/vnc/rfbproto.c8
-rw-r--r--krdc/vnc/threads.cpp20
-rw-r--r--krdc/vnc/threads.h6
-rw-r--r--krdc/vnc/vncprefs.ui4
-rw-r--r--krdc/vnc/vnctypes.h2
-rw-r--r--krdc/vnc/vncviewer.h2
21 files changed, 83 insertions, 83 deletions
diff --git a/krdc/events.h b/krdc/events.h
index d9856449..5100a23c 100644
--- a/krdc/events.h
+++ b/krdc/events.h
@@ -33,10 +33,10 @@
* REMOTE_VIEW_DISCONNECTING
* @li You can move from REMOTE_VIEW_DISCONNECTED to REMOTE_VIEW_CONNECTING
*
- * @ref KRemoteView::settqStatus() will follow this rules for you.
+ * @ref KRemoteView::setStatus() will follow this rules for you.
* (If you add/remove a state here, you must adapt it)
*/
-enum RemoteViewtqStatus {
+enum RemoteViewStatus {
REMOTE_VIEW_CONNECTING = 0,
REMOTE_VIEW_AUTHENTICATING = 1,
REMOTE_VIEW_PREPARING = 2,
@@ -78,13 +78,13 @@ const int StatusChangeEventType = 41002;
class StatusChangeEvent : public TQCustomEvent
{
private:
- RemoteViewtqStatus m_status;
+ RemoteViewStatus m_status;
public:
- StatusChangeEvent(RemoteViewtqStatus s) :
+ StatusChangeEvent(RemoteViewStatus s) :
TQCustomEvent(StatusChangeEventType),
m_status(s)
{};
- RemoteViewtqStatus status() const { return m_status; };
+ RemoteViewStatus status() const { return m_status; };
};
const int PasswordRequiredEventType = 41003;
diff --git a/krdc/hostprofiles.ui b/krdc/hostprofiles.ui
index c67ab2ca..25f52e48 100644
--- a/krdc/hostprofiles.ui
+++ b/krdc/hostprofiles.ui
@@ -82,7 +82,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>117</width>
<height>21</height>
diff --git a/krdc/keycapturewidget.ui b/krdc/keycapturewidget.ui
index e90411b1..f08c9e7a 100644
--- a/krdc/keycapturewidget.ui
+++ b/krdc/keycapturewidget.ui
@@ -40,7 +40,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>112</width>
<height>21</height>
@@ -51,7 +51,7 @@
<property name="name">
<cstring>keyLabel</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>100</width>
<height>0</height>
@@ -77,7 +77,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>111</width>
<height>21</height>
diff --git a/krdc/kfullscreenpanel.cpp b/krdc/kfullscreenpanel.cpp
index 81cd49e7..0c85cfdd 100644
--- a/krdc/kfullscreenpanel.cpp
+++ b/krdc/kfullscreenpanel.cpp
@@ -88,7 +88,7 @@ void KFullscreenPanel::setChild(TQWidget *child) {
}
void KFullscreenPanel::doLayout() {
- TQSize s = tqsizeHint();
+ TQSize s = sizeHint();
setFixedSize(s);
setGeometry((m_fsResolution.width() - s.width())/2, 0,
s.width(), s.height());
diff --git a/krdc/krdc.cpp b/krdc/krdc.cpp
index 41d96a70..2ace992f 100644
--- a/krdc/krdc.cpp
+++ b/krdc/krdc.cpp
@@ -165,7 +165,7 @@ bool KRDC::start()
m_scrollView = new TQScrollView2(this, "remote scrollview");
m_scrollView->setFrameStyle(TQFrame::NoFrame);
- m_scrollView->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Expanding,
+ m_scrollView->setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding,
TQSizePolicy::Expanding));
switch(m_protocol)
@@ -198,8 +198,8 @@ bool KRDC::start()
// note that the disconnectedError() will be disconnected when kremoteview
// is completely initialized
connect(m_view, TQT_SIGNAL(disconnectedError()), TQT_SIGNAL(disconnectedError()));
- connect(m_view, TQT_SIGNAL(statusChanged(RemoteViewtqStatus)),
- TQT_SLOT(changeProgress(RemoteViewtqStatus)));
+ connect(m_view, TQT_SIGNAL(statusChanged(RemoteViewStatus)),
+ TQT_SLOT(changeProgress(RemoteViewStatus)));
connect(m_view, TQT_SIGNAL(showingPasswordDialog(bool)),
TQT_SLOT(showingPasswordDialog(bool)));
connect(m_keyCaptureDialog, TQT_SIGNAL(keyPressed(XEvent*)),
@@ -210,7 +210,7 @@ bool KRDC::start()
return ret_status;
}
-void KRDC::changeProgress(RemoteViewtqStatus s) {
+void KRDC::changeProgress(RemoteViewStatus s) {
if (!m_progressDialog) {
m_progressDialog = new KProgressDialog(0, 0, TQString(),
"1234567890", false);
@@ -373,10 +373,10 @@ void KRDC::enableFullscreen(bool on)
m_view->switchFullscreen(on);
}
-TQSize KRDC::tqsizeHint()
+TQSize KRDC::sizeHint()
{
if ((m_isFullscreen != WINDOW_MODE_FULLSCREEN) && m_toolbar) {
- int dockHint = m_dockArea->tqsizeHint().height();
+ int dockHint = m_dockArea->sizeHint().height();
dockHint = dockHint < 1 ? 1 : dockHint; // fix wrong size hint
return TQSize(m_view->framebufferSize().width(),
dockHint + m_view->framebufferSize().height());
@@ -495,7 +495,7 @@ void KRDC::switchToFullscreen(bool scaling)
TQLabel *hostLabel = new TQLabel(t);
hostLabel->setName("kde toolbar widget");
- hostLabel->tqsetAlignment(TQt::AlignCenter);
+ hostLabel->setAlignment(TQt::AlignCenter);
hostLabel->setText(" "+m_host+" ");
t->insertWidget(FS_HOSTLABEL_ID, 150, hostLabel);
t->setItemAutoSized(FS_HOSTLABEL_ID, true);
@@ -575,7 +575,7 @@ void KRDC::switchToNormal(bool scaling)
if (!m_toolbar) {
m_dockArea = new TQDockArea(Qt::Horizontal, TQDockArea::Normal, this);
- m_dockArea->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::MinimumExpanding,
+ m_dockArea->setSizePolicy(TQSizePolicy(TQSizePolicy::MinimumExpanding,
TQSizePolicy::Fixed));
KToolBar *t = new KToolBar(m_dockArea);
m_toolbar = t;
@@ -633,7 +633,7 @@ void KRDC::switchToNormal(bool scaling)
m_view->resize(m_view->framebufferSize());
}
- setMaximumSize(tqsizeHint());
+ setMaximumSize(sizeHint());
repositionView(false);
@@ -644,7 +644,7 @@ void KRDC::switchToNormal(bool scaling)
m_initialWindowSize = TQSize();
}
else if (!scalingChanged)
- resize(tqsizeHint());
+ resize(sizeHint());
show();
if (scalingChanged)
m_view->update();
@@ -681,14 +681,14 @@ void KRDC::iconify()
}
void KRDC::toolbarChanged() {
- setMaximumSize(tqsizeHint());
+ setMaximumSize(sizeHint());
// resize window when toolbar is docked and it was maximized
TQSize fs = m_view->framebufferSize();
TQSize cs = size();
TQSize cs1(cs.width(), cs.height()-1); // adjusted for TQDockArea.height()==1
if ((fs == cs) || (fs == cs1))
- resize(tqsizeHint());
+ resize(sizeHint());
}
diff --git a/krdc/krdc.h b/krdc/krdc.h
index d78dc959..a264e11e 100644
--- a/krdc/krdc.h
+++ b/krdc/krdc.h
@@ -127,7 +127,7 @@ protected:
virtual void mouseMoveEvent(TQMouseEvent *e);
virtual bool event(TQEvent *e);
virtual bool eventFilter(TQObject *watched, TQEvent *e);
- virtual TQSize tqsizeHint();
+ virtual TQSize sizeHint();
public:
KRDC(WindowMode wm = WINDOW_MODE_AUTO,
@@ -145,7 +145,7 @@ public:
static void setLastHost(const TQString &host);
private slots:
- void changeProgress(RemoteViewtqStatus s);
+ void changeProgress(RemoteViewStatus s);
void showingPasswordDialog(bool b);
void showProgressTimeout();
diff --git a/krdc/kremoteview.cpp b/krdc/kremoteview.cpp
index a3dbce40..76ae6267 100644
--- a/krdc/kremoteview.cpp
+++ b/krdc/kremoteview.cpp
@@ -24,11 +24,11 @@ KRemoteView::KRemoteView(TQWidget *parent,
m_status(REMOTE_VIEW_DISCONNECTED) {
}
-enum RemoteViewtqStatus KRemoteView::status() {
+enum RemoteViewStatus KRemoteView::status() {
return m_status;
}
-void KRemoteView::settqStatus(RemoteViewtqStatus s) {
+void KRemoteView::setStatus(RemoteViewStatus s) {
if (m_status == s)
return;
@@ -49,8 +49,8 @@ void KRemoteView::settqStatus(RemoteViewtqStatus s) {
// smooth state transition
int origState = (int)m_status;
for (int i = origState; i < (int)s; i++) {
- m_status = (RemoteViewtqStatus) i;
- emit statusChanged((RemoteViewtqStatus) i);
+ m_status = (RemoteViewStatus) i;
+ emit statusChanged((RemoteViewStatus) i);
}
}
}
diff --git a/krdc/maindialogbase.ui b/krdc/maindialogbase.ui
index 96f04ff0..c1757016 100644
--- a/krdc/maindialogbase.ui
+++ b/krdc/maindialogbase.ui
@@ -48,7 +48,7 @@
<property name="name">
<cstring>m_serverInput</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>250</width>
<height>0</height>
@@ -149,7 +149,7 @@ Remote Desktop Connection only supports systems that use VNC.</string>
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>34</width>
<height>16</height>
@@ -188,7 +188,7 @@ Remote Desktop Connection only supports systems that use VNC.</string>
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>34</width>
<height>16</height>
@@ -226,7 +226,7 @@ Remote Desktop Connection only supports systems that use VNC.</string>
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>100</width>
<height>0</height>
diff --git a/krdc/maindialogwidget.cpp b/krdc/maindialogwidget.cpp
index eed72b99..df4d687b 100644
--- a/krdc/maindialogwidget.cpp
+++ b/krdc/maindialogwidget.cpp
@@ -175,8 +175,8 @@ void MainDialogWidget::enableBrowsingArea( bool enable )
m_browsingPanel->setMaximumSize(0, 0);
m_browsingPanel->setEnabled(false);
m_browseButton->setText(m_browseButton->text().replace("<<", ">>"));
- int h = tqminimumSize().height()-hOffset;
- setMinimumSize(tqminimumSize().width(), (h > 0) ? h : 0);
+ int h = minimumSize().height()-hOffset;
+ setMinimumSize(minimumSize().width(), (h > 0) ? h : 0);
resize(width(), height()-hOffset);
TQTimer::singleShot( 0, parentWidget(), TQT_SLOT( adjustSize() ) );
diff --git a/krdc/rdp/krdpview.cpp b/krdc/rdp/krdpview.cpp
index 4e5bc632..672b7b00 100644
--- a/krdc/rdp/krdpview.cpp
+++ b/krdc/rdp/krdpview.cpp
@@ -120,13 +120,13 @@ KRdpView::~KRdpView()
// returns the size of the framebuffer
TQSize KRdpView::framebufferSize()
{
- return m_container->tqsizeHint();
+ return m_container->sizeHint();
}
// returns the suggested size
-TQSize KRdpView::tqsizeHint()
+TQSize KRdpView::sizeHint()
{
- return tqmaximumSize();
+ return maximumSize();
}
// start closing the connection
@@ -303,7 +303,7 @@ bool KRdpView::start()
return false;
}
- settqStatus(REMOTE_VIEW_CONNECTING);
+ setStatus(REMOTE_VIEW_CONNECTING);
return true;
}
@@ -340,9 +340,9 @@ void KRdpView::setViewOnly(bool s)
void KRdpView::connectionOpened(WId /*window*/)
{
- TQSize size = m_container->tqsizeHint();
+ TQSize size = m_container->sizeHint();
- settqStatus(REMOTE_VIEW_CONNECTED);
+ setStatus(REMOTE_VIEW_CONNECTED);
setFixedSize(size);
m_container->setFixedSize(size);
emit changeSize(size.width(), size.height());
@@ -353,7 +353,7 @@ void KRdpView::connectionOpened(WId /*window*/)
void KRdpView::connectionClosed()
{
emit disconnected();
- settqStatus(REMOTE_VIEW_DISCONNECTED);
+ setStatus(REMOTE_VIEW_DISCONNECTED);
m_quitFlag = true;
}
@@ -361,7 +361,7 @@ void KRdpView::processDied(KProcess */*proc*/)
{
if(m_status == REMOTE_VIEW_CONNECTING)
{
- settqStatus(REMOTE_VIEW_DISCONNECTED);
+ setStatus(REMOTE_VIEW_DISCONNECTED);
if(m_clientVersion.isEmpty())
{
KMessageBox::error(0, i18n("Connection attempt to host failed."),
diff --git a/krdc/rdp/krdpview.h b/krdc/rdp/krdpview.h
index c34d3c27..7f6180b5 100644
--- a/krdc/rdp/krdpview.h
+++ b/krdc/rdp/krdpview.h
@@ -69,7 +69,7 @@ class KRdpView : public KRemoteView
// functions regarding the window
virtual TQSize framebufferSize(); // returns the size of the remote view
- TQSize tqsizeHint(); // returns the suggested size
+ TQSize sizeHint(); // returns the suggested size
virtual bool viewOnly();
virtual bool startFullscreen();
diff --git a/krdc/rdp/rdpprefs.ui b/krdc/rdp/rdpprefs.ui
index 0d37422a..46f791a0 100644
--- a/krdc/rdp/rdpprefs.ui
+++ b/krdc/rdp/rdpprefs.ui
@@ -40,7 +40,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>70</width>
<height>21</height>
@@ -84,7 +84,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>280</width>
<height>0</height>
@@ -325,7 +325,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>280</width>
<height>0</height>
diff --git a/krdc/vnc/kvncview.cpp b/krdc/vnc/kvncview.cpp
index 02cd3a78..eabadc7d 100644
--- a/krdc/vnc/kvncview.cpp
+++ b/krdc/vnc/kvncview.cpp
@@ -219,7 +219,7 @@ bool KVncView::checkLocalKRfb() {
if (m_port != portNum)
return true;
- settqStatus(REMOTE_VIEW_DISCONNECTED);
+ setStatus(REMOTE_VIEW_DISCONNECTED);
KMessageBox::error(0,
i18n("It is not possible to connect to a local desktop sharing service."),
i18n("Connection Failure"));
@@ -295,7 +295,7 @@ bool KVncView::start() {
useKWallet = hp->useKWallet();
}
- settqStatus(REMOTE_VIEW_CONNECTING);
+ setStatus(REMOTE_VIEW_CONNECTING);
m_cthread.start();
setBackgroundMode(TQt::NoBackground);
@@ -390,7 +390,7 @@ void KVncView::customEvent(TQCustomEvent *e)
}
else if (e->type() == StatusChangeEventType) {
StatusChangeEvent *sce = (StatusChangeEvent*) e;
- settqStatus(sce->status());
+ setStatus(sce->status());
if (m_status == REMOTE_VIEW_CONNECTED) {
emit connected();
setFocus();
@@ -458,7 +458,7 @@ void KVncView::customEvent(TQCustomEvent *e)
}
else if (e->type() == FatalErrorEventType) {
FatalErrorEvent *fee = (FatalErrorEvent*) e;
- settqStatus(REMOTE_VIEW_DISCONNECTED);
+ setStatus(REMOTE_VIEW_DISCONNECTED);
switch (fee->errorCode()) {
case ERROR_CONNECTION:
KMessageBox::error(0,
@@ -683,8 +683,8 @@ void KVncView::focusOutEvent(TQFocusEvent *) {
unpressModifiers();
}
-TQSize KVncView::tqsizeHint() {
- return tqmaximumSize();
+TQSize KVncView::sizeHint() {
+ return maximumSize();
}
void KVncView::setRemoteMouseTracking(bool s) {
diff --git a/krdc/vnc/kvncview.h b/krdc/vnc/kvncview.h
index 7fdf402c..7a8c9a2c 100644
--- a/krdc/vnc/kvncview.h
+++ b/krdc/vnc/kvncview.h
@@ -84,7 +84,7 @@ public:
DotCursorState dotCursorState = DOT_CURSOR_AUTO,
const TQString &encodings = TQString());
~KVncView();
- TQSize tqsizeHint();
+ TQSize sizeHint();
void drawRegion(int x, int y, int w, int h);
void lockFramebuffer();
void unlockFramebuffer();
diff --git a/krdc/vnc/threads.cpp b/krdc/vnc/threads.cpp
index f4e0eefe..ebd02c8e 100644
--- a/krdc/vnc/threads.cpp
+++ b/krdc/vnc/threads.cpp
@@ -47,7 +47,7 @@ ControllerThread::ControllerThread(KVncView *v, WriterThread &wt, volatile bool
{
}
-void ControllerThread::changetqStatus(RemoteViewtqStatus s) {
+void ControllerThread::changeStatus(RemoteViewStatus s) {
m_status = s;
TQApplication::postEvent(m_view, new StatusChangeEvent(s));
}
@@ -86,13 +86,13 @@ void ControllerThread::run() {
return;
}
if (m_quitFlag) {
- changetqStatus(REMOTE_VIEW_DISCONNECTED);
+ changeStatus(REMOTE_VIEW_DISCONNECTED);
return;
}
- changetqStatus(REMOTE_VIEW_AUTHENTICATING);
+ changeStatus(REMOTE_VIEW_AUTHENTICATING);
- enum InittqStatus s = InitialiseRFBConnection();
+ enum InitStatus s = InitialiseRFBConnection();
if (s != INIT_OK) {
if (s == INIT_CONNECTION_FAILED)
sendFatalError(ERROR_IO);
@@ -103,7 +103,7 @@ void ControllerThread::run() {
else if (s == INIT_AUTHENTICATION_FAILED)
sendFatalError(ERROR_AUTHENTICATION);
else if (s == INIT_ABORTED)
- changetqStatus(REMOTE_VIEW_DISCONNECTED);
+ changeStatus(REMOTE_VIEW_DISCONNECTED);
else
sendFatalError(ERROR_INTERNAL);
return;
@@ -120,18 +120,18 @@ void ControllerThread::run() {
m_waiter.wait(1000);
if (m_quitFlag) {
- changetqStatus(REMOTE_VIEW_DISCONNECTED);
+ changeStatus(REMOTE_VIEW_DISCONNECTED);
return;
}
- changetqStatus(REMOTE_VIEW_PREPARING);
+ changeStatus(REMOTE_VIEW_PREPARING);
if (!SetFormatAndEncodings()) {
sendFatalError(ERROR_INTERNAL);
return;
}
- changetqStatus(REMOTE_VIEW_CONNECTED);
+ changeStatus(REMOTE_VIEW_CONNECTED);
m_wthread.start();
@@ -143,11 +143,11 @@ void ControllerThread::run() {
}
m_quitFlag = true;
- changetqStatus(REMOTE_VIEW_DISCONNECTED);
+ changeStatus(REMOTE_VIEW_DISCONNECTED);
m_wthread.kick();
}
-enum RemoteViewtqStatus ControllerThread::status() {
+enum RemoteViewStatus ControllerThread::status() {
return m_status;
}
diff --git a/krdc/vnc/threads.h b/krdc/vnc/threads.h
index 4bb77ef3..08ca4c20 100644
--- a/krdc/vnc/threads.h
+++ b/krdc/vnc/threads.h
@@ -102,18 +102,18 @@ protected:
class ControllerThread : public TQThread {
private:
KVncView *m_view;
- enum RemoteViewtqStatus m_status;
+ enum RemoteViewStatus m_status;
WriterThread &m_wthread;
volatile bool &m_quitFlag;
volatile bool m_desktopInitialized;
TQWaitCondition m_waiter;
- void changetqStatus(RemoteViewtqStatus s);
+ void changeStatus(RemoteViewStatus s);
void sendFatalError(ErrorCode s);
public:
ControllerThread(KVncView *v, WriterThread &wt, volatile bool &quitFlag);
- enum RemoteViewtqStatus status();
+ enum RemoteViewStatus status();
void desktopInit();
void kick();
diff --git a/krdc/vnc/vncprefs.ui b/krdc/vnc/vncprefs.ui
index f569bb3f..ad38431c 100644
--- a/krdc/vnc/vncprefs.ui
+++ b/krdc/vnc/vncprefs.ui
@@ -104,7 +104,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>280</width>
<height>0</height>
@@ -124,7 +124,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>84</width>
<height>16</height>
diff --git a/krdc/vnc/vnctypes.h b/krdc/vnc/vnctypes.h
index 4dba9a5c..fae12549 100644
--- a/krdc/vnc/vnctypes.h
+++ b/krdc/vnc/vnctypes.h
@@ -54,7 +54,7 @@ typedef struct {
} AppData;
-enum InittqStatus {
+enum InitStatus {
INIT_OK = 0,
INIT_NAME_RESOLUTION_FAILURE = 1,
INIT_PROTOCOL_FAILURE = 2,
diff --git a/krdc/vnc/vncviewer.h b/krdc/vnc/vncviewer.h
index 4b1f6cb9..285357b9 100644
--- a/krdc/vnc/vncviewer.h
+++ b/krdc/vnc/vncviewer.h
@@ -155,7 +155,7 @@ typedef struct {
extern PointerImage pointerImages[];
extern int ConnectToRFBServer(const char *hostname, int port);
-extern enum InittqStatus InitialiseRFBConnection(void);
+extern enum InitStatus InitialiseRFBConnection(void);
extern Bool SetFormatAndEncodings(void);
extern Bool SendIncrementalFramebufferUpdateRequest(void);
extern Bool SendFramebufferUpdateRequest(int x, int y, int w, int h,
diff --git a/krdc/kremoteview.h b/krdc/kremoteview.h
index 0b0ae11c..af4fb0ef 100644
--- a/krdc/kremoteview.h
+++ b/krdc/kremoteview.h
@@ -152,7 +152,7 @@ public:
* Checks whether the view is currently quitting.
* @return true if it is quitting
* @see startQuitting()
- * @see settqStatus()
+ * @see setStatus()
*/
virtual bool isQuitting() = 0;
@@ -173,7 +173,7 @@ public:
* dialogs to the user) and start connecting. Should not block
* without running the event loop (so displaying a dialog is ok).
* When the view starts connecting the application must call
* @ref settqStatus() with the status REMOTE_VIEW_CONNECTING.
* @return true if successful (so far), false
* otherwise
* @see connected()
@@ -186,9 +186,9 @@ public:
/**
* Returns the current status of the connection.
* @return the status of the connection
- * @see settqStatus()
+ * @see setStatus()
*/
- enum RemoteViewtqStatus status();
+ enum RemoteViewStatus status();
public slots:
/**
@@ -253,7 +253,7 @@ signals:
* Emitted when the status of the view changed.
* @param s the new status
*/
- void statusChanged(RemoteViewtqStatus s);
+ void statusChanged(RemoteViewStatus s);
/**
* Emitted when the password dialog is shown or hidden.
@@ -275,21 +275,21 @@ protected:
/**
* The status of the remote view.
*/
- enum RemoteViewtqStatus m_status;
+ enum RemoteViewStatus m_status;
/**
* Set the status of the connection.
* Emits a statusChanged() signal.
* Note that the states need to be set in a certain order,
* see @ref RemoteViewtqStatus. settqStatus() will try to do this
* transition automatically, so if you are in REMOTE_VIEW_CONNECTING
* and call settqStatus(REMOTE_VIEW_PREPARING), settqStatus() will
* emit a REMOTE_VIEW_AUTHENTICATING and then REMOTE_VIEW_PREPARING.
* If you transition backwards, it will emit a
* REMOTE_VIEW_DISCONNECTED before doing the transition.
* @param s the new status
*/
- virtual void settqStatus(RemoteViewtqStatus s);
+ virtual void setStatus(RemoteViewStatus s);
};
#endif
@@ -173,7 +173,7 @@ public:
* without running the event loop (so displaying a dialog is ok).
* When the view starts connecting the application must call
- * @ref settqStatus() with the status REMOTE_VIEW_CONNECTING.
+ * @ref setStatus() with the status REMOTE_VIEW_CONNECTING.
* @return true if successful (so far), false
* otherwise
@@ -275,21 +275,21 @@ protected:
* Emits a statusChanged() signal.
* Note that the states need to be set in a certain order,
- * see @ref RemoteViewtqStatus. settqStatus() will try to do this
+ * see @ref RemoteViewStatus. setStatus() will try to do this
* transition automatically, so if you are in REMOTE_VIEW_CONNECTING
@@ -275,21 +275,21 @@ protected:
* transition automatically, so if you are in REMOTE_VIEW_CONNECTING
- * and call settqStatus(REMOTE_VIEW_PREPARING), settqStatus() will
+ * and call setStatus(REMOTE_VIEW_PREPARING), setStatus() will
* emit a REMOTE_VIEW_AUTHENTICATING and then REMOTE_VIEW_PREPARING.
* If you transition backwards, it will emit a
diff --git a/krdc/vnc/rfbproto.c b/krdc/vnc/rfbproto.c
index 13676bb6..22909533 100644
--- a/krdc/vnc/rfbproto.c
+++ b/krdc/vnc/rfbproto.c
@@ -159,7 +159,7 @@ ConnectToRFBServer(const char *hostname, int port)
* InitialiseRFBConnection.
*/
-enum InittqStatus
+enum InitStatus
InitialiseRFBConnection()
{
rfbProtocolVersionMsg pv;
@@ -734,12 +734,12 @@ static void *MakeSoftCursor(int bpp, int cursorWidth, int cursorHeight,
/*********************************************************************
* HandletqCursorShape(). Support for XCursor and RichCursor tqshape
* updates. We emulate cursor operating on the frame buffer (that is
* why we call it "software cursor").
********************************************************************/
-static Bool HandletqCursorShape(int xhot, int yhot, int width, int height, CARD32 enc)
+static Bool HandleCursorShape(int xhot, int yhot, int width, int height, CARD32 enc)
{
int bytesPerPixel;
size_t bytesPerRow, bytesMaskData;
@@ -956,7 +956,7 @@ HandleRFBServerMessage()
if (rect.encoding == rfbEncodingXCursor ||
rect.encoding == rfbEncodingRichCursor) {
- if (!HandletqCursorShape(rect.r.x, rect.r.y, rect.r.w, rect.r.h,
+ if (!HandleCursorShape(rect.r.x, rect.r.y, rect.r.w, rect.r.h,
rect.encoding)) {
return False;
}
@@ -734,12 +734,12 @@ static void *MakeSoftCursor(int bpp, int cursorWidth, int cursorHeight,
/*********************************************************************
- * HandletqCursorShape(). Support for XCursor and RichCursor tqshape
+ * HandleCursorShape(). Support for XCursor and RichCursor tqshape
* updates. We emulate cursor operating on the frame buffer (that is
* why we call it "software cursor").